@@ -43,6 +43,10 @@ specify).
 from .loci import Locus
 from .process import Process
 
+# network generators
+from .generator import NetworkGenerator
+from .standard_generators import FixedNetwork, ERNetwork, BANetwork
+
 # networks with dynamical processes
 from .networkdynamics import Dynamics
 from .synchronousdynamics import SynchronousDynamics
@@ -55,6 +59,7 @@ from .compartmentedmodel import CompartmentedModel, CompartmentedLocus, Compartm
 from .sir_model import SIR
 from .sis_model import SIS
 from .sirs_model import SIRS
+from .seir_model import SEIR
 
 # variant disease models
 from .sir_model_fixed_recovery import SIR_FixedRecovery
