@@ -18,7 +18,7 @@
 # along with epydemic. If not, see <http://www.gnu.org/licenses/gpl.html>.
 
 from epydemic import Locus, Process
-import random
+import math
 import numpy
 import collections
 
@@ -57,7 +57,7 @@ class CompartmentedNodeLocus(CompartmentedLocus):
         return [ self._compartment ]
 
     def addHandler(self, g, n):
-        '''A nodeis added to the network. 
+        '''A node is added to the network. 
 
         :param, g: the network
         :param n: the node'''
@@ -255,6 +255,14 @@ class CompartmentedModel(Process):
         dist = []
         for cp in self._compartments.items():
             dist.append(cp)
+ 
+        # sanity-check the distribution
+        a = 0.0
+        for (_, p) in dist:
+            a += p
+        if not math.isclose(a, 1.0):
+            raise Exception('Bad initial compartment distribution (probabilities don\'t sum to one')
+
         return dist
 
     def initialCompartments( self ):
@@ -269,12 +277,13 @@ class CompartmentedModel(Process):
 
         # assign nodes to compartments
         g = self.network()
+        rng = numpy.random.default_rng()
         for n in g.nodes():
             # select a compartment according to the initial distribution
-            r = random.random()
+            r = rng.random()
             a = 0.0
             for (c, p) in dist:
-                a = a + p
+                a += p
                 if r <= a:
                     # change node's compartment
                     self.changeCompartment(n, c)
@@ -348,6 +357,18 @@ class CompartmentedModel(Process):
         :param p: the initial occupancy probability (defaults to  0.0)'''
         self._compartments[c] = p
 
+    def changeCompartmentInitialOccupancy(self, c, p):
+        '''Change the initial occupancy probability for a compartment. This method
+        is used when sub-classing an existing model: it only makes sense during the
+        build process (see :meth:`build`) before the model is initialised in
+        :meth:`setUp`.
+
+        :param c: the compartment
+        :param p: the new initial occupation probability'''
+        if c not in self.compartments():
+            raise Exception('Compartment {c} not defined in model'.format(c=c))
+        self._compartments[c] = p
+
     def trackNodesInCompartment(self, c, name = None):
         '''Add a locus tracking nodes in a given compartment.
 
@@ -383,10 +404,14 @@ class CompartmentedModel(Process):
         :param l: (optional) the locus
         :returns: the locus'''
         locus = super(CompartmentedModel,self).addLocus(n, l)
-        for c in locus.compartments():
-            if c not in self._effects.keys():
-                self._effects[c] = []
-            self._effects[c].append((locus.addHandler, locus.leaveHandler, locus.enterHandler, locus.removeHandler))
+
+        # if we've added a compartmented locus, add handler functions for
+        # when its population changes
+        if isinstance(locus, CompartmentedLocus):
+            for c in locus.compartments():
+                if c not in self._effects.keys():
+                    self._effects[c] = []
+                self._effects[c].append((locus.addHandler, locus.leaveHandler, locus.enterHandler, locus.removeHandler))
 
     def _handlerCompartments(self, e):
         '''Return the compartments that a given element's change might affect.
@@ -500,14 +525,16 @@ class CompartmentedModel(Process):
         data[self.OCCUPIED] = True
         data[self.T_OCCUPIED] = t
         
-    def addNode(self, n, c, **kwds):
-        '''Add a node to the working network, adding it to the appropriate compartment.
+    def addNode(self, n, c=None, **kwds):
+        '''Add a node to the working network, adding it to the appropriate compartment
+        if one is provided].
 
         :param n: the new node
-        :param c: compartment for the node
+        :param c: (optional) compartment for the node
         :param kwds: (optional) node attributes'''
         super(CompartmentedModel, self).addNode(n, **kwds)
-        self.setCompartment(n, c)
+        if c is not None:
+            self.setCompartment(n, c)
 
     def removeNode(self, n):
         '''Remove a node from the working network, updating any affected compartments.
@@ -520,7 +547,7 @@ class CompartmentedModel(Process):
         # remove the node
         super(CompartmentedModel, self).removeNode(n)
 
-    def addEdge(self, n, m,  **kwds):
+    def addEdge(self, n, m, **kwds):
         '''Add an edge between nodes, adding the edge to any appropriate compartments.
 
         :param n: the start node
